package com.ruoyi.project.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TpElevatorModel;
import com.ruoyi.project.business.domain.vo.paramSelectItem.AreaElevatorModelParaVO;
import com.ruoyi.project.business.domain.vo.paramSelectItem.ElevatorModeParamlVo;
import com.ruoyi.project.business.domain.vo.paramSelectItem.TpElevatorModelVo;
import com.ruoyi.project.business.dto.TpElevatorModelDto;
import java.util.List;
import org.apache.ibatis.annotations.Param;


/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-25
 */
public interface TpElevatorModelMapper extends BaseMapper<TpElevatorModel> {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TpElevatorModel selectTpElevatorModelById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tpElevatorModel 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TpElevatorModel> selectTpElevatorModelList(TpElevatorModel tpElevatorModel);


    /**
     * description: listForComponents 服务于共同组件的查询
     *
     * @param param: 前端查询参数
     * @return java.util.List<com.ruoyi.project.business.dto.TpElevatorModelDto>
     * @author jubs 😀
     * @date 2024/4/29 14:06
     */
    List<TpElevatorModelDto> listForComponents(TpElevatorModelDto param);

    /**
     * 新增【请填写功能名称】
     *
     * @param tpElevatorModel 【请填写功能名称】
     * @return 结果
     */
    public int insertTpElevatorModel(TpElevatorModel tpElevatorModel);

    /**
     * 修改【请填写功能名称】
     *
     * @param tpElevatorModel 【请填写功能名称】
     * @return 结果
     */
    public int updateTpElevatorModel(TpElevatorModel tpElevatorModel);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTpElevatorModelById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTpElevatorModelByIds(Long[] ids);

    List<TpElevatorModel> selectTpElevatorModelListNew(TpElevatorModelVo tpElevatorModel);

    List<TpElevatorModel> selectTpElevatorModelListNewByCountryUser(TpElevatorModelVo tpElevatorModel);

    ElevatorModeParamlVo selectTpElevatorModelParamById(Long id);

    List<AreaElevatorModelParaVO> selectTpElevatorModelParamSelectItemById(Long id);

    List<AreaElevatorModelParaVO> selectTpElevatorModelParamSelectItemAllById(Long id);

    ElevatorModeParamlVo selectTpElevatorModelParamOptionById(@Param("id") Long id,
        @Param("quotationFlag") boolean quotationFlag);
}
